﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Entidades;

namespace Datos
{
    public class AmicsDA : BaseDades, IDataAcces<Amics>
    {
            #region Miembros de IDataAccess<Amics>
            //funció per obtenir totes les llistes de usuaris i amics
            public List<Amics> GetAll()
            {
                DataClasses1DataContext dc = GetDC();
                IQueryable<Amics> query = from amics
                                               in dc.Amics
                                               select amics;
                return ConsultaLista<Amics>(query);
            }

            //funció per afegir una nova relació usuari-amic
            public void Adicionar(Amics item)
            {
                DataClasses1DataContext dc = GetDC();
                dc.Amics.InsertOnSubmit(item);
                dc.SubmitChanges();
            }
            
            //funció per a eliminar una relació usuari-amic
            public void Eliminar(Amics item)
            {
                DataClasses1DataContext dc = GetDC();
                dc.Amics.Attach(item);
                dc.Amics.DeleteOnSubmit(item);
                dc.SubmitChanges();
            }
            
            //funció per actualitzar una relació usuari-amic
            public void Actualizar(Amics nuevoItem, Amics originalItem)
            {
                DataClasses1DataContext dc = GetDC();
                dc.Amics.Attach(nuevoItem, originalItem);
                dc.SubmitChanges();
            }
            
            //funció per obtenir la llista de tots els amics d'un usuari
            //a la taula l'usuari pot trovar-se al camp id_usuari o id_amic i per tant cerquem als 2 camps
            public List<Amics> GetUserFriends(int id)
            {
                DataClasses1DataContext dc = GetDC();
                                
                IQueryable<Amics> query = from amics
                                               in dc.Amics
                                           where amics.id_usuari==id || amics.id_amic==id
                                           select amics;

                return ConsultaLista<Amics>(query);
            }
            
            //funció per a comprobar si dos usuaris son amics
            public List<Amics> GetFriend(int myId, int friend_id)
            {
                DataClasses1DataContext dc = GetDC();

                IQueryable<Amics> query = from amics
                                               in dc.Amics
                                          where (amics.id_usuari == myId && amics.id_amic == friend_id) || (amics.id_usuari == friend_id && amics.id_amic == myId)
                                          select amics;

                return ConsultaLista<Amics>(query);
            }
            
            //Funció que actualitza el camp estat quan un usuari accepta o rebutja una solicitut d'amistat
            public void ActualitzaEstat(int friendId, int myId, int nouEstat)
            {                
                DataClasses1DataContext dc = GetDC();
                Amics amic = dc.Amics.Single(a => a.id_usuari == friendId && a.id_amic == myId);
                amic.estat = nouEstat;
                dc.SubmitChanges();
            }
            
        }
            #endregion
}