﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Entidades;

namespace Datos
{
    public class ComentariDA : BaseDades, IDataAcces<Comentari>
    {
            #region Miembros de IDataAccess<Comentari>
            
            //funció per a llistar tots els comentaris de la bbdd
            public List<Comentari> GetAll()
            {
                DataClasses1DataContext dc = GetDC();
                IQueryable<Comentari> query = from comentari
                                               in dc.Comentari
                                               select comentari;
                return ConsultaLista<Comentari>(query);
            }

            //funció per afegir un nou comentari
            public void Adicionar(Comentari item)
            {
                Comentari com = new Comentari();
                com.id_comentari = SelectLast() + 1;
                com.id_publicacio = item.id_publicacio;
                com.id_usuari = item.id_usuari;
                com.comentari_text = item.comentari_text;
                
                DataClasses1DataContext dc = GetDC();
                dc.Comentari.InsertOnSubmit(com);
                dc.SubmitChanges();
            }
            
            //funció per eliminar un comentari
            public void Eliminar(Comentari item)
            {
                DataClasses1DataContext dc = GetDC();
                dc.Comentari.Attach(item);
                dc.Comentari.DeleteOnSubmit(item);
                dc.SubmitChanges();
            }

            //funció per actualitzar un comentari
            public void Actualizar(Comentari nuevoItem, Comentari originalItem)
            {
                DataClasses1DataContext dc = GetDC();
                dc.Comentari.Attach(nuevoItem, originalItem);
                dc.SubmitChanges();
            }
            
            //funció per seleccionar el id del darrer comentari
            public int SelectLast()
            {
                DataClasses1DataContext dc = GetDC();
                int query = (from comentari
                                               in dc.Comentari
                             select (int?)comentari.id_comentari).Max() ?? 0;
                return (query);
            }

            //funció per obtenir tots els comentaris d'una publicació
            //ordenats de més a menys recent
            public List<Comentari> GetComentaris(int publicacio_id)
            {
                DataClasses1DataContext dc = GetDC();                
                IQueryable<Comentari> query = from comentari
                                               in dc.Comentari
                                               where comentari.id_publicacio == publicacio_id
                                               orderby comentari.id_comentari descending
                                               select comentari;
                return ConsultaLista<Comentari>(query);
            }
        }
            #endregion
}