﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Entidades;

namespace Datos
{
    public class MediaDA : BaseDades, IDataAcces<Media>
        {
            #region Miembros de IDataAccess<Media>

            //funció per a llistar tots els videos i fotos enviades per els usuaris
            public List<Media> GetAll()
            {
                DataClasses1DataContext dc = GetDC();
                IQueryable<Media> query = from media
                                               in dc.Media
                                               select media;
                return ConsultaLista<Media>(query);
            }
            
            //funció per a obtenir el media(foto o video) afegida a una publicació
            public List<Media> GetMediaPublicacio(int id)
            {
                DataClasses1DataContext dc = GetDC();
                IQueryable<Media> query = from media                                       
                                          in dc.Media
                                          where media.id_publicacio == id
                                          select media;
                return ConsultaLista<Media>(query);
            }
            
            //funció per afegir un nou media
            public void Adicionar(Media item)
            {
                Media media = new Media();
                media.id_media = SelectLast() + 1;
                media.id_publicacio = item.id_publicacio;
                media.id_tipus = item.id_tipus;
                media.src_media = item.src_media;
                
                DataClasses1DataContext dc = GetDC();
                dc.Media.InsertOnSubmit(media);
                dc.SubmitChanges();
            }
            
            //funció per eliminar un media
            public void Eliminar(Media item)
            {
                DataClasses1DataContext dc = GetDC();
                dc.Media.Attach(item);
                dc.Media.DeleteOnSubmit(item);
                dc.SubmitChanges();
            }
            
            //funció per actualitzar un media
            public void Actualizar(Media nuevoItem, Media originalItem)
            {
                DataClasses1DataContext dc = GetDC();
                dc.Media.Attach(nuevoItem, originalItem);
                dc.SubmitChanges();
            }
            
            //funció per a seleccionar el id del darrer media de la bbdd
            public int SelectLast()
            {
                DataClasses1DataContext dc = GetDC();
                int query = (from media
                                               in dc.Media
                             select (int?)media.id_media).Max() ?? 0;
                return (query);
            }
        }
            #endregion
}