﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Entidades;

namespace Datos
{
    public class PublicacioDA : BaseDades, IDataAcces<Publicacio>
    {
        #region Miembros de IDataAccess<Publicacio>

        //funció per obtenir totes les publicacions de la bbdd
        public List<Publicacio> GetAll()
        {
            DataClasses1DataContext dc = GetDC();
            IQueryable<Publicacio> query = from publicacio
                                           in dc.Publicacio
                                           select publicacio;
            return ConsultaLista<Publicacio>(query);
        }

        //funció per obtenir el id de la darrera publicació
        public int SelectLast()
        {
            DataClasses1DataContext dc = GetDC();
            int query = (from publicacio
                                           in dc.Publicacio
                                           select (int?)publicacio.id_publicacio).Max()?? 0;
            return (query);
        }

        //funció per afegir una nova publicació
        //no s'utilitza però està definida a la Interfaz i hem de declarar-la
        public void Adicionar(Publicacio item)
        {
            //not used
        }

        //funció per afegir una nova publicació
        //retorna el id de la nova publicació per a poder afegir a continuació el video o foto en cas que l'usuari ho hagi afegit
        public int AdicionarPublicacio(Publicacio item)
        {
            Publicacio publi = new Publicacio();
            publi.id_publicacio = SelectLast() + 1;
            publi.descripcio = item.descripcio;
            publi.id_tematica = item.id_tematica;
            publi.id_tipus = item.id_tipus;
            publi.id_usuari = item.id_usuari;
            publi.data = item.data;

            DataClasses1DataContext dc = GetDC();
            dc.Publicacio.InsertOnSubmit(publi);
            dc.SubmitChanges();

            return publi.id_publicacio;
        }

        //funció per eliminar una publicació
        public void Eliminar(Publicacio item)
        {
            DataClasses1DataContext dc = GetDC();
            dc.Publicacio.Attach(item);
            dc.Publicacio.DeleteOnSubmit(item);
            dc.SubmitChanges();
        }

        //funció per actualitzar una publicació
        public void Actualizar(Publicacio nuevoItem, Publicacio originalItem)
        {
            DataClasses1DataContext dc = GetDC();
            dc.Publicacio.Attach(nuevoItem, originalItem);
            dc.SubmitChanges();
        }

        //funció per obtenir totes les publicacions de l'usuari i dels seus amics
        //ordenats per data de més actual a menys
        //només obtenim aquelles publicacions per a les quals la temàtica siga una de les escollides per l'usuari
        public List<Publicacio> GetFriendsAndUserPub(int usu_id)
        {
            DataClasses1DataContext dc = GetDC();
            var friends = (from amics in dc.Amics
                           where (amics.id_usuari == usu_id)
                           select amics.id_amic);
            var friends2 = (from amics in dc.Amics
                           where (amics.id_amic == usu_id)
                           select amics.id_usuari);
            var tematiques = (from usuaritematica in dc.UsuariTematica
                              where (usuaritematica.id_usuari == usu_id)
                              select usuaritematica.id_tematica);
            IQueryable<Publicacio> query = from publicacio
                                           in dc.Publicacio
                                           where publicacio.id_usuari == usu_id || friends.Contains(publicacio.id_usuari) || friends2.Contains(publicacio.id_usuari)
                                           where tematiques.Contains(publicacio.id_tematica)
                                           orderby publicacio.data descending
                                           select publicacio;
            return ConsultaLista<Publicacio>(query);
        }
    }
        #endregion
}