﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Entidades;

namespace Datos
{
    public class UsuariDA : BaseDades, IDataAcces<Usuari>
        {
            #region Miembros de IDataAccess<Usuari>
            //funció per obtrnir tots els usuaris enregistrats
            public List<Usuari> GetAll()
            {
                DataClasses1DataContext dc = GetDC();
                IQueryable<Usuari> query = from usuari
                                               in dc.Usuari
                                               select usuari;
                return ConsultaLista<Usuari>(query);
            }

            //funció per a seleccionar el id del darrer usuari
            public int SelectLast()
            {
                DataClasses1DataContext dc = GetDC();
                int query = (from usuari
                                               in dc.Usuari
                             select (int?)usuari.id_usuari).Max() ?? 0;
                return (query);
            }

            //funció per afegir un nou usuari
            public void Adicionar(Usuari item)
            {
                item.id_usuari = SelectLast() + 1;
                DataClasses1DataContext dc = GetDC();
                dc.Usuari.InsertOnSubmit(item);
                dc.SubmitChanges();
            }

            //funció per eliminar un usuari
            public void Eliminar(Usuari item)
            {
                DataClasses1DataContext dc = GetDC();
                dc.Usuari.Attach(item);
                dc.Usuari.DeleteOnSubmit(item);
                dc.SubmitChanges();
            }

            //funció per actualitzar un usuari
            public void Actualizar(Usuari nuevoItem, Usuari originalItem)
            {
                DataClasses1DataContext dc = GetDC();
                dc.Usuari.Attach(nuevoItem, originalItem);
                dc.SubmitChanges();
            }

            //funció pre comprovar si existeix un usuari per a un determinat email i contrasenya
            //Validació d'usuaris
            public int GetUsuari(String name, String pass)
            {
                DataClasses1DataContext dc = GetDC();
                int id = 0;
                IQueryable<Usuari> query = from usuari
                                               in dc.Usuari
                                               where usuari.email==name && usuari.pwd==pass
                                           select usuari;
                foreach (var row in query)
                {
                    id = row.id_usuari;
                }
                
                return id;
            }

            //funció per comprovar si existeix un usuari per a un determinat email
            //Validació d'usuaris
            public int GetUserEmail(String name)
            {
                DataClasses1DataContext dc = GetDC();
                int id = 0;
                IQueryable<Usuari> query = from usuari
                                               in dc.Usuari
                                           where usuari.email == name
                                           select usuari;
                foreach (var row in query)
                {
                    id = row.id_usuari;
                }

                return id;
            }

            //Funció per a cercar un usuari per el seu nom o cognoms
            //Contains de linq equival a Like '%%' en SQL
            public List<Usuari> SearchUser(string text)
            {
                
                DataClasses1DataContext dc = GetDC();
                                var query = from usuari
                                               in dc.Usuari
                                           where usuari.nom.Contains(text) || usuari.cognoms.Contains(text)
                                           select usuari;
                return query.ToList();
            }

            //funció per obtenir les dades d'un usuari per el seu id
            public List<Usuari> GetUser(int id)
            {
                DataClasses1DataContext dc = GetDC();
                var query = from usuari
                               in dc.Usuari
                            where usuari.id_usuari==id
                            select usuari;
                return ConsultaLista<Usuari>(query);
            }
            
            //Funció per obtenir els amics d'un usuari
            public List<Usuari> GetUserFriends(int id)
            {
                DataClasses1DataContext dc = GetDC();

                var friends = (from amics in dc.Amics
                               where (amics.id_usuari == id)
                               select amics.id_amic);
                IQueryable<Usuari> query = from usuari
                                               in dc.Usuari
                                               where friends.Contains(usuari.id_usuari)
                                               select usuari;

                return ConsultaLista<Usuari>(query);
            }

            //funció per obtenir les solicituts d'amistat pendents
            public List<Usuari> GetSolicitudsPendents(int id)
            {
                DataClasses1DataContext dc = GetDC();

                var friends = (from amics in dc.Amics
                               where (amics.id_amic == id && amics.estat==0)
                               select amics.id_usuari);
                IQueryable<Usuari> query = from usuari
                                               in dc.Usuari
                                               where friends.Contains(usuari.id_usuari)
                                               select usuari;

                return ConsultaLista<Usuari>(query);
            }

            //funció per obtenir tots els amics d'un usuari (estat acceptat = 1)
            public List<Usuari> GetAmics(int id)
            {
                DataClasses1DataContext dc = GetDC();
                
                IQueryable<Usuari> query = (from amics
                                               in dc.Amics
                                           where amics.estat == 1
                                           where amics.id_usuari == id || amics.id_amic == id
                                           join usuari in dc.Usuari on amics.id_usuari equals usuari.id_usuari
                                           where usuari.id_usuari!=id
                                           select usuari).Union
                                           (from amics
                                               in dc.Amics
                                            where amics.estat == 1
                                            where amics.id_usuari == id || amics.id_amic == id
                                            join usuari in dc.Usuari on amics.id_amic equals usuari.id_usuari
                                            where usuari.id_usuari != id
                                            select usuari);

                return ConsultaLista<Usuari>(query);
            }

            //funció per actualitzar la imatge de perfil d'un usuari
            public void ActualitzaImatge(int userId, string photoName)
            {
                DataClasses1DataContext dc = GetDC();
                Usuari usuari = dc.Usuari.Single(u => u.id_usuari == userId);
                usuari.imatge = photoName;
                dc.SubmitChanges();
            }

            
        }
            #endregion
}