﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using System.Data;
using System.IO;
using Entidades;
using Negoci;

namespace Presentacio
{
    public partial class UserProfile : System.Web.UI.Page
    {
        string sImageFileExtension;
        int profile_id;
        private List<Tematica> tematiques;
        private List<UsuariTematica> usuariTematiques;

        protected void Page_Load(object sender, EventArgs e)
        {
            //Cotrolem que està registrat i si no enviem a pàgina de login
            if (HttpContext.Current.Session["UserId"] == null)
                Response.Redirect("Default.aspx");

            if (!Page.IsPostBack)
            {
                if (!String.IsNullOrEmpty(Request.QueryString["Id"]))
                    profile_id = int.Parse(Request.QueryString["Id"].ToString());
                else
                    profile_id = Convert.ToInt32(Session["UserId"]);
                //Mostrem informació del perfil dels usuaris
                //Si no passam id mostrem el perfil de l'usuari actiu
                GetUserDetails(profile_id);

                //només el propietari del compte pot veure tota la informació del perfil
                if (profile_id == Convert.ToInt32(Session["UserId"]))
                {
                    GetUserFriendsRequest(profile_id);
                    GetUserFriends(profile_id);
                    
                    //mostrem les opcions temàtiques a seleccionar 
                    cargarTematicas();
                }
                else
                {
                    //amaguem totes les altres seccions de la pàgina
                    btnTematicas.Visible = false;
                    lblPhotoSideHeading.Visible = false;
                    UploadUserPhoto.Visible = false;
                    ButtonMakeProfile.Visible = false;
                    FriendRequestList.Visible = false;
                    FriendList.Visible = false;
                    chklabel.Visible = false;
                    lblamics.Visible = false;
                    Lblsol.Visible = false;

                }
            }
        }

        public void GetUserDetails(int id)
        {

            UsuariBL bl = new UsuariBL();
            List<Usuari> ListaUsuaris = bl.GetUser(id);
            foreach (Usuari U in ListaUsuaris)
            {
                if (U.imatge == null || U.imatge=="")
                    UserImage.ImageUrl = "~/UserImage/noimatge.jpg";
                else
                    UserImage.ImageUrl = "~/UserImage/" + U.imatge.ToString();

                LabelNom.Text = U.nom.ToString();
                LabelCognoms.Text = U.cognoms.ToString();


            }

        }
        protected void AddToFriend_Click(object sender, EventArgs e)
        {
            if (!object.Equals(Session["UserId"], null))
            {
                if (Object.Equals(Session["UserId"], Request.QueryString["Id"]))
                {
                    lblError.Text = "Aquest és el teu perfil";
                    lblError.Visible = true;
                }
                else
                {
                    AmicsBL bl = new AmicsBL();
                    List<Amics> ListaAmics = bl.GetFriend(Convert.ToInt32(Session["UserId"]), Convert.ToInt32(profile_id));

                    if (ListaAmics.Count > 0)
                    {
                        foreach (Amics A in ListaAmics)
                        {
                            if (A.estat.ToString() == "1")
                            {
                                lblError.Text = "Ja sou amics";
                                lblError.Visible = true;
                            }
                            if (A.estat.ToString() == "0")
                            {
                                lblError.Text = "Petició pendent de ser acceptada";
                                lblError.Visible = true;
                            }
                            if (A.estat.ToString() == "2")
                            {
                                lblError.Text = "Denegació d'amistat";
                                lblError.Visible = true;
                            }
                        }
                    }
                    else
                    {
                        Amics amics = new Amics();
                        amics.id_usuari = Convert.ToInt32(Session["UserId"]);
                        amics.id_amic = Convert.ToInt32(profile_id);
                        amics.estat = 0;

                        bl.Adicionar(amics);

                        lblError.Text = "Petició d'amistat enviada";
                        lblError.Visible = true;
                    }
                }
            }
            else
            {
                Response.Redirect("~/Default.aspx");
            }

        }


        public void GetUserFriendsRequest(int id)
        {
            UsuariBL bl = new UsuariBL();
            List<Usuari> ListaUsuaris = bl.GetSolicitudsPendents(id);

            if (ListaUsuaris.Count > 0)
            {
                FriendRequestList.DataSource = ListaUsuaris;
                FriendRequestList.DataBind();
            }
        }

        public string getHREF(int id)
        {
            int Id = Convert.ToInt32(id);
            if (Id > 0)
            {
                return ResolveUrl("~/UserProfile.aspx?Id=" + id);
            }
            else
            {
                return ResolveUrl("~/Default.aspx");
            }
        }

        public string getSRC(string imgSRC)
        {

            string ImageName = "UserImage/noimatge.jpg";
            if (imgSRC == "")
            {
                return ImageName;
            }
            else
            {
                return "UserImage/" + imgSRC;
            }
        }

        //funció per acceptar o denegar sol·licituds d'amistat
        protected void FriendRequestList_ItemCommand(object source, DataListCommandEventArgs e)
        {
            if (!object.Equals(Session["UserId"], null))
            {
                if (e.CommandName == "Accept")
                {
                    int SenderFriendId = Convert.ToInt32(((HtmlInputHidden)e.Item.FindControl("hiddenId")).Value);
                    int MyID = Convert.ToInt32(Session["UserId"]);

                    AmicsBL bl = new AmicsBL();
                    bl.ActualitzaEstat(SenderFriendId, MyID, 1);
                    Response.Redirect("UserProfile.aspx");
                }
                if (e.CommandName == "Deny")
                {
                    int SenderFriendId = Convert.ToInt32(((HtmlInputHidden)e.Item.FindControl("hiddenId")).Value);
                    int MyID = Convert.ToInt32(Session["UserId"]);

                    AmicsBL bl = new AmicsBL();
                    bl.ActualitzaEstat(SenderFriendId, MyID, 2);
                    Response.Redirect("UserProfile.aspx");
                }
            }
        }

        //funció per a llistar els amics de l'usuari
        public void GetUserFriends(int id)
        {
            UsuariBL bl = new UsuariBL();
            List<Usuari> ListaUsuaris = bl.GetAmics(id);

            if (ListaUsuaris.Count > 0)
            {
                FriendList.DataSource = ListaUsuaris;
                FriendList.DataBind();
            }
        }
        

        public string getUserHREF(object sURL)
        {
            //DataRowView dRView = (DataRowView)sURL;
            //string Id = dRView["UserId"].ToString();
            return ResolveUrl("~/UserProfile.aspx");
        }

        //funció que actualitza la imatge de perfil de l'usuari
        protected void ButtonMakeProfile_Click1(object sender, EventArgs e)
        {
            if (UploadUserPhoto.PostedFile != null)
            {
                string myMap = MapPath("~/").ToLower();
                Random r = new Random();
                int next = r.Next();
                string ImageName = UploadUserPhoto.PostedFile.FileName;
                                
                sImageFileExtension = ImageName.Substring(ImageName.LastIndexOf(".")).ToLower();
                if (sImageFileExtension == ".gif" || sImageFileExtension == ".png" || sImageFileExtension == ".jpg" || sImageFileExtension == ".jpeg" || sImageFileExtension == ".bmp")
                {
                    string ImageSaveURL = myMap + "UserImage/" + next + sImageFileExtension;
                    try
                    {
                        UploadUserPhoto.PostedFile.SaveAs(ImageSaveURL);
                        string nom = next + sImageFileExtension;
                        UsuariBL bl = new UsuariBL();
                        bl.ActualitzaImatge(Convert.ToInt32(Session["UserId"]), nom);

                        Response.Redirect("~/UserProfile.aspx");
                    }
                    catch (Exception ex)
                    {
                        lblError.Text = "Error al enviar la imatge. Torna a enviar-la";
                        lblError.Visible = true;
                    }
                }
                else
                {
                    lblError.Text = "Extensió d'imatge no permessa. Ha de ser png, jpg, bmp o gif";
                    lblError.Visible = true;
                }
            }
            else
            {
                //ToSaveImageName = "No";
                sImageFileExtension = "Image";
            }
        }

        //mètode per carregar les temàtiques disponibles
        protected void cargarTematicas()
        {
            List<Tematica> info = new List<Tematica>();


            TematicaBL bl = new TematicaBL();
            tematiques = bl.GetAll();

            for (int i = 0; i < tematiques.Count(); i++)
            {//Carreguem la llista a la taula
                Tematica tematica = new Tematica();

                tematica.id_tematica = Convert.ToInt32(tematiques.ElementAt(i).id_tematica);
                tematica.descripcio = tematiques.ElementAt(i).descripcio.ToString();

                info.Add(tematica);

            }


            CheckBoxList1.DataSource = info;
            CheckBoxList1.DataBind();

            //Carreguem les tematiques seleccionades per el usuari i enregistrades a la bbdd

            int id = Convert.ToInt32(Session["UserId"]);
            UsuariTematicaBL ut = new UsuariTematicaBL();
            usuariTematiques = ut.GetUserTemes(id);

            for (int i = 0; i < usuariTematiques.Count; i++)
            {
                ListItem currentCheckBox = CheckBoxList1.Items.FindByValue(usuariTematiques.ElementAt(i).id_tematica.ToString());
                if (currentCheckBox != null)
                {
                    currentCheckBox.Selected = true;
                }
            }
        }

        //funció per actualitzar les temàtiques d l'usuari
        protected void btnTematicas_Click(object sender, EventArgs e)
        {
            int id = Convert.ToInt32(Session["UserId"]);
            UsuariTematicaBL ut = new UsuariTematicaBL();
            usuariTematiques = ut.GetUserTemes(id);
            for (int i = 0; i < CheckBoxList1.Items.Count; i++)
            {
                if (CheckBoxList1.Items[i].Selected)
                {
                    //si no existeix aquesta relacio usuari-tematica a la taula la afegim
                    //en cas contrari no fem res
                    bool existeix = false;
                    for (int j = 0; j < usuariTematiques.Count; j++)
                    {
                        if (usuariTematiques.ElementAt(j).id_tematica.ToString() == CheckBoxList1.Items[i].Value.ToString())
                        {
                            existeix = true;
                        }
                    }
                    //si no existeix aquesta relació la afegim
                    if (existeix == false)
                    {
                        UsuariTematica usute = new UsuariTematica();
                        usute.id_usuari = id;
                        usute.id_tematica = Convert.ToInt32(CheckBoxList1.Items[i].Value.ToString());
                        ut.Adicionar(usute);
                    }
                }
                else
                {
                    // si no està marcat comprovem si avanç estava i ho esborrem

                    for (int j = 0; j < usuariTematiques.Count; j++)
                    {
                        if (usuariTematiques.ElementAt(j).id_tematica.ToString() == CheckBoxList1.Items[i].Value.ToString())
                        {
                            //existeix a la bbd per tant l'esborrem
                            UsuariTematica usute = new UsuariTematica();
                            usute.id_usuari = id;
                            usute.id_tematica = Convert.ToInt32(CheckBoxList1.Items[i].Value.ToString());
                            ut.Eliminar(usute);
                        }
                    }
                }
            }
            Label3.Text = "Les temàtiques s'han actualitzat correctament";
        }
    }
}